#!/bin/bash

function fatal() {
    echo "$0: fatal error: $*" >&2
    exit 1
}

function get_prop() {
    local _ret_vn="$1"
    local _i="$2"
    shift 2

    local _v
    for key in "$@"
    do
	_v=$(jq ".tokens[$_i].$key" < "$json_file") || \
	    fatal "failed to get $key of item $_i"
	[[ -z "$_v" || "$_v" == "null" ]] || {
	    printf -v "$_ret_vn" "%s" "$_v"
	    return 0
	}
    done

    fatal "failed to get name"
}

function get_secret() {
    local _ret_vn="$1"
    local _i="$2"

    local _s
    _s="$(echo $(jq ".tokens[$_i].secret" < "$json_file" | awk '/[0-9]/ {gsub(",",""); printf "%02x\n", $1}' | sed -r 's#^ffffffffffffff##') | sed 's# ##g')" || \
	fatal "failed to get secret of index: $_i"
    printf -v "$_ret_vn" "%s" "$_s"
}

(( $# == 1 )) || {
    echo "$0: usage: $0 <json-file>" >&2
    exit 2
}

json_file="$1"

[ -f "$json_file" ] || fatal "no such file: $json_file"

count=$(jq '.tokens | length' < "$json_file") || fatal "failed to count items"

for (( i=0; i < $count; i++ ))
do
    get_prop name "$i" "issuerAlt" "issuerExt" "issuerInt" "label"
    get_prop digits "$i" "digits"
    get_prop period "$i" "period"
    get_prop counter "$i" "counter"
    get_secret secret "$i"

    name="${name//\"/}"
    name="${name// /_}"
    name="${name//\./_}"

cat <<EOF
[${name,,}]
    digits = $digits
    totp_x = $period
    totp_t0 = $counter
    encoding = hex
    secret = $secret

EOF
done

exit 0
